package com.fs.live.service;


import com.fs.live.domain.LiveGift;

import java.util.List;

/**
 * 直播间礼物配置Service接口
 *
 * @author fs
 * @date 2025-07-08
 */
public interface ILiveGiftService {
    /**
     * 查询直播间礼物配置
     *
     * @param giftId 直播间礼物配置主键
     * @return 直播间礼物配置
     */
    LiveGift selectLiveGiftByGiftId(Long giftId);

    /**
     * 查询直播间礼物配置列表
     *
     * @param liveGift 直播间礼物配置
     * @return 直播间礼物配置集合
     */
    List<LiveGift> selectLiveGiftList(LiveGift liveGift);

    /**
     * 新增直播间礼物配置
     *
     * @param liveGift 直播间礼物配置
     * @return 结果
     */
    int insertLiveGift(LiveGift liveGift);

    /**
     * 修改直播间礼物配置
     *
     * @param liveGift 直播间礼物配置
     * @return 结果
     */
    int updateLiveGift(LiveGift liveGift);

    /**
     * 批量删除直播间礼物配置
     *
     * @param giftIds 需要删除的直播间礼物配置主键集合
     * @return 结果
     */
    int deleteLiveGiftByGiftIds(Long[] giftIds);

    /**
     * 删除直播间礼物配置信息
     *
     * @param giftId 直播间礼物配置主键
     * @return 结果
     */
    int deleteLiveGiftByGiftId(Long giftId);
}
